package VMOMI::HostMountInfoInaccessibleReason;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
